@@ -46,22 +46,28 @@ class OptionChain:
         df[1] = df[1].apply(lambda x : re.findall('\D+' , x)[0])
         df = df[df[1] == self.symbol]
         strikes = np.sort(df[6].unique())
-        return strikes[1] - strikes[0]
+        step = strikes[1]-strikes[0];
+        for i in range(2 , len(strikes)):
+            step = min(step, strikes[i]-strikes[i-1]);
+        return step
 
     def get_option_symbols(self ):
         expiry = self.expiry.strftime('%y%m%d')
         future_atm = round(self.future_price / self.strike_step ) * self.strike_step
         start_strike = int(future_atm - self.strike_step * int(self.chain_length / 2 ) )
         end_strike = int(future_atm + self.strike_step * int( self.chain_length / 2) )
-        symbols = list(map(lambda x: f'{self.symbol}{expiry}{x}CE', range( start_strike , end_strike  , self.strike_step )))
-        symbols.extend(list(map(lambda x: f'{self.symbol}{expiry}{x}PE', range( start_strike , end_strike  , self.strike_step ))))
+        req_strikes = np.arange( start_strike , end_strike  , self.strike_step )
+        if isinstance( self.strike_step , float ) :
+            req_strikes = list(map(lambda x: int(x) if x.is_integer() else x , req_strikes))
+        symbols = list(map(lambda x: f'{self.symbol}{expiry}{x}CE', req_strikes))
+        symbols.extend(list(map(lambda x: f'{self.symbol}{expiry}{x}PE', req_strikes )))
         return symbols
 
     def init_dataframe(self):
         df = pd.DataFrame(columns=['symbols' , 'strike' , 'type' , 'ltp' , 'ltt' ,'volume' , 'oi' , 'prev_oi' , 'oi_change' ,
                                     'oi_change_perc' , 'bid' , 'bid_qty' , 'ask' , 'ask_qty'])
         df.symbols = self.option_symbols
-        df.strike = df.symbols.apply(lambda x: str(re.findall('\d+' , x )[0])[6:])
+        df.strike = df.symbols.apply(lambda x: str(re.search(r"\d+(\.\d+)?", x ).group(0) )[6:])
         df.type = df.symbols.apply(lambda x: re.findall('\D+' , x )[-1] )
         df.set_index('symbols' , inplace=True)
         df.sort_values(by=['strike' , 'type'] , inplace=True)
@@ -80,9 +86,9 @@ class OptionChain:
             self.chain_dataframe.loc[td_obj.touchline_data[symb_id].symbol , ['ltp' , 'ltt'  , 'volume' ,  'oi' , 'prev_oi', 'oi_change' ,
                                                                                 'oi_change_perc','bid' , 'bid_qty' , 'ask' , 'ask_qty' ]] = [
                 td_obj.touchline_data[symb_id].ltp, td_obj.touchline_data[symb_id].timestamp , td_obj.touchline_data[symb_id].ttq ,
-                td_obj.touchline_data[symb_id].oi,td_obj.touchline_data[symb_id].prev_oi , td_obj.touchline_data[symb_id].oi - td_obj.touchline_data[symb_id].prev_oi ,
-                oi_change_perc , td_obj.touchline_data[symb_id].best_bid_price,td_obj.touchline_data[symb_id].best_bid_qty,
-                td_obj.touchline_data[symb_id].best_ask_price,td_obj.touchline_data[symb_id].best_ask_qty]
+                td_obj.touchline_data[symb_id].oi, td_obj.touchline_data[symb_id].prev_oi , td_obj.touchline_data[symb_id].oi - td_obj.touchline_data[symb_id].prev_oi ,
+                oi_change_perc , td_obj.touchline_data[symb_id].best_bid_price, td_obj.touchline_data[symb_id].best_bid_qty,
+                td_obj.touchline_data[symb_id].best_ask_price, td_obj.touchline_data[symb_id].best_ask_qty]
 
         while self.chain_status:
             for symb_id in symb_ids:
